==> ultracopier_2.2.4.7.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/es/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="328"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Comprar la versión Ultimate para financiar el desarrollo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="328"/>
        <source>Register your key</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="427"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>El archivo %1/%2, el tamaño: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="661"/>
        <source>Copy list</source>
        <translation>Lista de copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="663"/>
        <source>Move list</source>
        <translation>Lista de movimiento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1091"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1092"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1093"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1095"/>
        <source>File Name, 0KB</source>
        <translation>Nombre de archivo, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1289"/>
        <location filename="../../interface.cpp" line="1301"/>
        <location filename="../../interface.cpp" line="1313"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1388"/>
        <location filename="../../interface.cpp" line="1392"/>
        <location filename="../../interface.cpp" line="1394"/>
        <source>%1 %2% of %3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="284"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="285"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="286"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="482"/>
        <location filename="../../ThemesFactory.cpp" line="497"/>
        <location filename="../../ThemesFactory.cpp" line="512"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>De:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>Para:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;Más</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Cerca de finalización de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Limitar la velocidad de copia en:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Lista de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Mueve los elementos seleccionados a la parte superior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Mueva los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Bajar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Mueve los elementos seleccionados a la parte inferior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Agregar archivo/carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Eliminar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Exportar la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Importe la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Exportar los errores en la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Añadir archivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Mover archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Mueva la carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Copia el archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Copia la carpeta</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="267"/>
        <source>Show dual progression</source>
        <translation>Mostrar progresión dual</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Mostrar la velocidad como principales informaciones</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Uso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Comience con el &quot;botón más&quot; empujada</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Minimizar en cerca de la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Al final de la copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitar la velocidad de copia de</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="306"/>
        <source>Click to edit the color</source>
        <translation>Haga clic para editar el color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Informations</source>
        <translation>Informations</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Visualización</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="257"/>
        <source>Speed with progress bar</source>
        <translation>Velocidad con barra de progreso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="287"/>
        <source>Progression color</source>
        <translation>Progresión de color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="277"/>
        <source>Show progression in the title</source>
        <translation>Mostrar progresión en el título</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Siempre visible</translation>
    </message>
</context>
</TS>

==> ultracopier_2.2.6.0.orig.tar.xz: ultracopier-src/plugins/Themes/Oxygen/Languages/es/translation.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Themes</name>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Buy the Ultimate version to fund development</source>
        <translation>Comprar la versión Ultimate para financiar el desarrollo</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="341"/>
        <source>Register your key</source>
        <translation>Registra tu clave</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="440"/>
        <source>File %1/%2, size: %3/%4</source>
        <translation>El archivo %1/%2, el tamaño: %3/%4</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="674"/>
        <source>Copy list</source>
        <translation>Lista de copia</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="676"/>
        <source>Move list</source>
        <translation>Lista de movimiento</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1117"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1118"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1119"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1121"/>
        <source>File Name, 0KB</source>
        <translation>Nombre de archivo, 0KB</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1395"/>
        <location filename="../../interface.cpp" line="1407"/>
        <location filename="../../interface.cpp" line="1419"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
    <message>
        <location filename="../../interface.cpp" line="1494"/>
        <location filename="../../interface.cpp" line="1498"/>
        <location filename="../../interface.cpp" line="1500"/>
        <source>%1 %2% of %3</source>
        <translation>%1 %2% de %3</translation>
    </message>
</context>
<context>
    <name>ThemesFactory</name>
    <message>
        <location filename="../../ThemesFactory.cpp" line="294"/>
        <source>Don&apos;t close if errors are found</source>
        <translation>No cierre si se encuentran errores</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="295"/>
        <source>Never close</source>
        <translation>Nunca cierre</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="296"/>
        <source>Always close</source>
        <translation>Siempre cerrar</translation>
    </message>
    <message>
        <location filename="../../ThemesFactory.cpp" line="510"/>
        <location filename="../../ThemesFactory.cpp" line="525"/>
        <location filename="../../ThemesFactory.cpp" line="540"/>
        <source>Select a color</source>
        <translation>Seleccione un color</translation>
    </message>
</context>
<context>
    <name>interfaceCopy</name>
    <message>
        <location filename="../../interface.ui" line="44"/>
        <source>From:</source>
        <translation>De:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="74"/>
        <source>To:</source>
        <translation>Para:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="235"/>
        <source>&amp;More</source>
        <translation>&amp;Más</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="255"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausa</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="269"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="280"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Cancelar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="127"/>
        <source>Close on transfer completion</source>
        <translation>Cerca de finalización de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="295"/>
        <source>Limit copy speed to:</source>
        <translation>Limitar la velocidad de copia en:</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="338"/>
        <source>Transfer list</source>
        <translation>Lista de transferencia</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="361"/>
        <source>Move the selected items to the top</source>
        <translation>Mueve los elementos seleccionados a la parte superior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="387"/>
        <source>Move up the selected items</source>
        <translation>Mueva los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="413"/>
        <source>Move down the selected items</source>
        <translation>Bajar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="439"/>
        <source>Move the selected items to the bottom</source>
        <translation>Mueve los elementos seleccionados a la parte inferior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="465"/>
        <source>Add file/folder</source>
        <translation>Agregar archivo/carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="494"/>
        <source>Delete the selected items</source>
        <translation>Eliminar los elementos seleccionados</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="520"/>
        <source>Search</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="549"/>
        <source>Export the transfer list</source>
        <translation>Exportar la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="575"/>
        <source>Import the transfer list</source>
        <translation>Importe la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="630"/>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="637"/>
        <source>Next</source>
        <translation>Próximo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="672"/>
        <location filename="../../interface.ui" line="741"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="692"/>
        <source>Export the errors into transfer list</source>
        <translation>Exportar los errores en la lista de transferencias</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="731"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="736"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="750"/>
        <source>Interface</source>
        <translation>Interfaz</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="796"/>
        <source>Add file</source>
        <translation>Añadir archivo</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="805"/>
        <source>Add folder</source>
        <translation>Añadir carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="814"/>
        <source>Move file(s)</source>
        <translation>Mover archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="823"/>
        <source>Move folder</source>
        <translation>Mueva la carpeta</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="832"/>
        <source>Copy file(s)</source>
        <translation>Copia el archivo(s)</translation>
    </message>
    <message>
        <location filename="../../interface.ui" line="841"/>
        <source>Copy folder</source>
        <translation>Copia la carpeta</translation>
    </message>
</context>
<context>
    <name>themesOptions</name>
    <message>
        <location filename="../../themesOptions.ui" line="402"/>
        <source>Show dual progression</source>
        <translation>Mostrar progresión dual</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="219"/>
        <source>Show speed as main information</source>
        <translation>Mostrar la velocidad como principales informaciones</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="44"/>
        <source>Use</source>
        <translation>Uso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="173"/>
        <source>Start with the &quot;more button&quot; pushed</source>
        <translation>Comience con el &quot;botón más&quot; empujada</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="67"/>
        <source>Minimize on close to systray</source>
        <translation>Minimizar en cerca de la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="96"/>
        <source>At the end of the copy</source>
        <translation>Al final de la copia</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="103"/>
        <location filename="../../themesOptions.ui" line="137"/>
        <source>Limit copy speed to</source>
        <translation>Limitar la velocidad de copia de</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="53"/>
        <source>Start minimized</source>
        <translation>Iniciar minimizado</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="213"/>
        <source>Information</source>
        <translation>Informacións</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="269"/>
        <source>Click to edit the color</source>
        <translation>Haga clic para editar el color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="147"/>
        <source> KB/s</source>
        <translation> KB/s</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="190"/>
        <source>Save position</source>
        <translation>Guardar posicion</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="251"/>
        <source>Display</source>
        <translation>Visualización</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="368"/>
        <source>Speed with progress bar</source>
        <translation>Velocidad con barra de progreso</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="378"/>
        <source>Progression color</source>
        <translation>Progresión de color</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="388"/>
        <source>Show progression in the title</source>
        <translation>Mostrar progresión en el título</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="395"/>
        <source>General margin</source>
        <translation>Margen general</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="425"/>
        <source>General spacing</source>
        <translation>Espaciado general</translation>
    </message>
    <message>
        <location filename="../../themesOptions.ui" line="183"/>
        <source>Always on top</source>
        <translation>Siempre visible</translation>
    </message>
</context>
</TS>
